@@ -8,6 +8,7 @@ ml_gbt_classifier <- function(
   max_depth = 5L,
   step_size = 0.1,
   subsampling_rate = 1,
+  feature_subset_strategy = "auto",
   min_instances_per_node = 1L,
   max_bins = 32L,
   min_info_gain = 0,
@@ -35,6 +36,7 @@ ml_gbt_classifier.spark_connection <- function(
   max_depth = 5L,
   step_size = 0.1,
   subsampling_rate = 1,
+  feature_subset_strategy = "auto",
   min_instances_per_node = 1L,
   max_bins = 32L,
   min_info_gain = 0,
@@ -73,7 +75,9 @@ ml_gbt_classifier.spark_connection <- function(
     invoke("setLossType", loss_type) %>%
     invoke("setMaxIter", max_iter) %>%
     invoke("setStepSize", step_size) %>%
-    invoke("setSubsamplingRate", subsampling_rate)
+    invoke("setSubsamplingRate", subsampling_rate) %>%
+    jobj_set_param("setFeatureSubsetStrategy", feature_subset_strategy,
+                   "auto", "2.3.0")
 
   if(!rlang::is_null(thresholds) && spark_version(x) >= "2.2.0")
     jobj <- invoke(jobj, "setThresholds", thresholds)
@@ -92,6 +96,7 @@ ml_gbt_classifier.ml_pipeline <- function(
   max_depth = 5L,
   step_size = 0.1,
   subsampling_rate = 1,
+  feature_subset_strategy = "auto",
   min_instances_per_node = 1L,
   max_bins = 32L,
   min_info_gain = 0,
@@ -120,6 +125,7 @@ ml_gbt_classifier.tbl_spark <- function(
   max_depth = 5L,
   step_size = 0.1,
   subsampling_rate = 1,
+  feature_subset_strategy = "auto",
   min_instances_per_node = 1L,
   max_bins = 32L,
   min_info_gain = 0,
@@ -147,11 +153,9 @@ ml_gbt_classifier.tbl_spark <- function(
     predictor %>%
       ml_fit(x)
   } else {
-    call <- if (identical(sys.call(sys.parent())[[1]], quote(ml_gradient_boosted_trees)))
-      sys.call(sys.parent())
     ml_generate_ml_model(x, predictor, formula, features_col, label_col,
                          "classification", new_ml_model_gbt_classification,
-                         predicted_label_col, call = call)
+                         predicted_label_col)
   }
 }
 
@@ -175,6 +179,7 @@ ml_validator_gbt_classifier <- function(args, nms) {
       step_size <- ensure_scalar_double(step_size)
       subsampling_rate <- ensure_scalar_double(subsampling_rate)
       loss_type <- ensure_scalar_character(loss_type)
+      feature_subset_strategy <- ensure_scalar_character(feature_subset_strategy)
     }, old_new_mapping) %>%
     ml_extract_args(nms, old_new_mapping)
 }
@@ -190,7 +195,6 @@ new_ml_gbt_classification_model <- function(jobj) {
   new_ml_prediction_model(
     jobj,
     feature_importances = try_null(read_spark_vector(jobj, "featureImportances")),
-    num_trees = invoke(jobj, "numTrees"),
     num_classes = try_null(invoke(jobj, "numClasses")),
     num_features = invoke(jobj, "numFeatures"),
     total_num_nodes = invoke(jobj, "totalNumNodes"),
@@ -216,7 +220,6 @@ new_ml_model_gbt_classification <- function(
     pipeline, pipeline_model, model, dataset, formula,
     subclass = "ml_model_gbt_classification",
     .features = feature_names,
-    .index_labels = index_labels,
-    .call = call
+    .index_labels = index_labels
   )
 }
