@@ -124,11 +124,8 @@ ml_random_forest_regressor.tbl_spark <- function(
     predictor %>%
       ml_fit(x)
   } else {
-    call <- if (identical(sys.call(sys.parent())[[1]], quote(ml_random_forest)))
-      sys.call(sys.parent())
     ml_generate_ml_model(x, predictor, formula, features_col, label_col,
-                         "regression", new_ml_model_random_forest_regression,
-                         call = call)
+                         "regression", new_ml_model_random_forest_regression)
   }
 }
 
@@ -164,7 +161,6 @@ new_ml_random_forest_regression_model <- function(jobj) {
   new_ml_prediction_model(
     jobj,
     feature_importances = try_null(read_spark_vector(jobj, "featureImportances")),
-    num_trees = invoke(jobj, "numTrees"),
     num_features = invoke(jobj, "numFeatures"),
     total_num_nodes = invoke(jobj, "totalNumNodes"),
     tree_weights = invoke(jobj, "treeWeights"),
@@ -181,7 +177,6 @@ new_ml_model_random_forest_regression <- function(
   new_ml_model_regression(
     pipeline, pipeline_model, model, dataset, formula,
     subclass = "ml_model_random_forest_regression",
-    .features = feature_names,
-    .call = call
+    .features = feature_names
   )
 }
