@@ -56,19 +56,19 @@ java_context <- function(sc) {
 #' @name spark-api
 #' @export
 hive_context <- function(sc) {
-  if (!is.null(sc$hive_context))
-    sc$hive_context
-  else
-    create_hive_context(sc)
+  if (is.null(sc$hive_context))
+    sc$hive_context <- create_hive_context(sc)
+
+  sc$hive_context
 }
 
 #' @name spark-api
 #' @export
 spark_session <- function(sc) {
-  if (!is.null(sc$hive_context))
-    sc$hive_context
-  else
-    create_hive_context(sc)
+  if (is.null(sc$hive_context))
+    sc$hive_context <- create_hive_context(sc)
+
+  sc$hive_context
 }
 
 #' Retrieve the Spark Connection Associated with an R Object
@@ -78,6 +78,7 @@ spark_session <- function(sc) {
 #' @param x An \R object from which a \code{spark_connection} can be obtained.
 #' @param ... Optional arguments; currently unused.
 #'
+#' @exportClass spark_connection
 #' @export
 spark_connection <- function(x, ...) {
   UseMethod("spark_connection")
