@@ -4,7 +4,7 @@ sc <- testthat_spark_connection()
 test_that("sdf_copy_to works for scala serializer", {
   skip_on_cran()
 
-  df <- matrix(0, ncol = 5, nrow = 2) %>% as_data_frame()
+  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_data_frame()
   df_tbl <- sdf_copy_to(sc, df, overwrite = TRUE, serializer = "csv_file_scala")
 
   expect_equal(
@@ -16,7 +16,7 @@ test_that("sdf_copy_to works for scala serializer", {
 test_that("sdf_copy_to works for csv serializer", {
   skip_on_cran()
 
-  df <- matrix(0, ncol = 5, nrow = 2) %>% as_data_frame()
+  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_data_frame()
   df_tbl <- sdf_copy_to(sc, df, overwrite = TRUE, serializer = "csv_file")
 
   expect_equal(
@@ -24,3 +24,13 @@ test_that("sdf_copy_to works for csv serializer", {
     2
   )
 })
+
+test_that("spark_table_name() doesn't warn for multiline expression (#1386)", {
+  expect_warning(
+    spark_table_name(data.frame(foo = c(1, 2, 3),
+               bar = c(2, 1, 3),
+               foobar = c("a", "b", "c"))
+               ),
+    NA
+  )
+})
