@@ -45,7 +45,7 @@ test_that("'spark_apply()' works under Livy connections", {
   lc <- testthat_livy_connection()
 
   df <- data.frame(id = 10)
-  apply_tbl <- sdf_len(lc, 1) %>% spark_apply(function(x) 10)
+  apply_tbl <- sdf_len(lc, 1) %>% spark_apply(function(x) 10, packages = FALSE)
 
   expect_equal(apply_tbl %>% collect(), df)
 })
